@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -36,25 +36,32 @@
 #define _D_CHECK_INTEGRITY_ENTRY_H_
 
 #include "RequestGroupEntry.h"
+#include "ProgressAwareEntry.h"
+
+#include <vector>
+
+namespace aria2 {
 
 class IteratableValidator;
-typedef SharedHandle<IteratableValidator> IteratableValidatorHandle;
-class Command;
-typedef deque<Command*> Commands;
 class DownloadEngine;
+class FileAllocationEntry;
 
 class CheckIntegrityEntry : public RequestGroupEntry,
-			    public ProgressAwareEntry {
+                            public ProgressAwareEntry {
 protected:
-  IteratableValidatorHandle _validator;
+  SharedHandle<IteratableValidator> _validator;
+
+  void proceedFileAllocation(std::vector<Command*>& commands,
+                             const SharedHandle<FileAllocationEntry>& entry,
+                             DownloadEngine* e);
 public:
   CheckIntegrityEntry(RequestGroup* requestGroup, Command* nextCommand = 0);
 
   virtual ~CheckIntegrityEntry();
 
-  virtual int64_t getTotalLength();
+  virtual uint64_t getTotalLength();
 
-  virtual int64_t getCurrentLength();
+  virtual off_t getCurrentLength();
 
   virtual void validateChunk();
 
@@ -64,11 +71,15 @@ public:
 
   virtual void initValidator() = 0;
 
-  virtual Commands onDownloadFinished(DownloadEngine* e) = 0;
+  virtual void onDownloadFinished(std::vector<Command*>& commands,
+                                  DownloadEngine* e) = 0;
 
-  virtual Commands onDownloadIncomplete(DownloadEngine* e) = 0;
+  virtual void onDownloadIncomplete(std::vector<Command*>& commands,
+                                    DownloadEngine* e) = 0;
+
+  void cutTrailingGarbage();
 };
 
-typedef SharedHandle<CheckIntegrityEntry> CheckIntegrityEntryHandle;
-typedef deque<CheckIntegrityEntryHandle> CheckIntegrityEntries;
+} // namespace aria2
+
 #endif // _D_CHECK_INTEGRITY_ENTRY_H_
