@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -38,7 +38,7 @@
 #include <cstdlib>
 
 #include "DHTNode.h"
-#include "Util.h"
+#include "util.h"
 #include "a2functional.h"
 
 namespace aria2 {
@@ -48,8 +48,8 @@ const std::string DHTUnknownMessage::E("e");
 const std::string DHTUnknownMessage::UNKNOWN("unknown");
 
 DHTUnknownMessage::DHTUnknownMessage(const SharedHandle<DHTNode>& localNode,
-				     const unsigned char* data, size_t length,
-				     const std::string& ipaddr, uint16_t port):
+                                     const unsigned char* data, size_t length,
+                                     const std::string& ipaddr, uint16_t port):
   DHTMessage(localNode, SharedHandle<DHTNode>()),
   _length(length),
   _ipaddr(ipaddr),
@@ -92,9 +92,9 @@ std::string DHTUnknownMessage::toString() const
   }
   std::string sample(&_data[0], &_data[sampleLength]);
 
-  return strconcat("dht unknown Remote:", _ipaddr, ":", Util::uitos(_port),
-		   " length=", Util::uitos(_length),
-		   ", first 8 bytes(hex)=", Util::toHex(sample));
+  return strconcat("dht unknown Remote:", _ipaddr, ":", util::uitos(_port),
+                   " length=", util::uitos(_length),
+                   ", first 8 bytes(hex)=", util::toHex(sample));
 }
 
 } // namespace aria2
