@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -38,7 +38,7 @@
 #include "common.h"
 
 #include <map>
-#include <deque>
+#include <vector>
 #include <string>
 #include <iosfwd>
 
@@ -71,7 +71,7 @@ public:
   void put(const std::string& name, const std::string& value);
   bool defined(const std::string& name) const;
   const std::string& getFirst(const std::string& name) const;
-  std::deque<std::string> get(const std::string& name) const;
+  std::vector<std::string> get(const std::string& name) const;
   unsigned int getFirstAsUInt(const std::string& name) const;
   uint64_t getFirstAsULLInt(const std::string& name) const;
 
@@ -140,6 +140,8 @@ public:
 
   static const std::string LAST_MODIFIED;
 
+  static const std::string ACCEPT_ENCODING;
+
   static const std::string HTTP_1_1;
 
   static const std::string S200;
