@@ -1,8 +1,9 @@
 #include "DefaultAuthResolver.h"
 #include "prefs.h"
+#include "AuthConfig.h"
 #include <cppunit/extensions/HelperMacros.h>
 
-using namespace std;
+namespace aria2 {
 
 class DefaultAuthResolverTest : public CppUnit::TestFixture {
 
@@ -13,15 +14,16 @@ class DefaultAuthResolverTest : public CppUnit::TestFixture {
 private:
   //NetrcHandle _netrc;
   //SharedHandle<Option> _option;
-  DefaultAuthResolverHandle _resolver;
+  SharedHandle<DefaultAuthResolver> _resolver;
 public:
   void setUp()
   {
     //_netrc = new Netrc();
     //_option = new Option();
-    _resolver = new DefaultAuthResolver();
+    _resolver.reset(new DefaultAuthResolver());
     //_factory->setOption(_option.get());
-    _resolver->setDefaultAuthConfig(new AuthConfig("foo", "bar"));
+    _resolver->setDefaultAuthConfig
+      (SharedHandle<AuthConfig>(new AuthConfig("foo", "bar")));
   }
 
   void testResolveAuthConfig_without_userDefined();
@@ -33,13 +35,16 @@ CPPUNIT_TEST_SUITE_REGISTRATION( DefaultAuthResolverTest );
 
 void DefaultAuthResolverTest::testResolveAuthConfig_without_userDefined()
 {
-  AuthConfigHandle authConfig = _resolver->resolveAuthConfig("localhost");
-  CPPUNIT_ASSERT_EQUAL(string("foo:bar"), authConfig->getAuthText());
+  SharedHandle<AuthConfig> authConfig = _resolver->resolveAuthConfig("localhost");
+  CPPUNIT_ASSERT_EQUAL(std::string("foo:bar"), authConfig->getAuthText());
 }
 
 void DefaultAuthResolverTest::testResolveAuthConfig_with_userDefined()
 {
-  _resolver->setUserDefinedAuthConfig(new AuthConfig("myname", "mypasswd"));
-  AuthConfigHandle authConfig = _resolver->resolveAuthConfig("localhost");
-  CPPUNIT_ASSERT_EQUAL(string("myname:mypasswd"), authConfig->getAuthText());
+  _resolver->setUserDefinedAuthConfig
+    (SharedHandle<AuthConfig>(new AuthConfig("myname", "mypasswd")));
+  SharedHandle<AuthConfig> authConfig = _resolver->resolveAuthConfig("localhost");
+  CPPUNIT_ASSERT_EQUAL(std::string("myname:mypasswd"), authConfig->getAuthText());
 }
+
+} // namespace aria2
